searchNodes=[{"ref":"DateTimeParser.html","title":"DateTimeParser","type":"module","doc":"DateTimeParser is a tokenizer for strings that attempts to parse into a DateTime, NaiveDateTime if timezone is not determined, Date, or Time. The biggest ambiguity between datetime formats is whether it&#39;s ymd (year month day), mdy (month day year), or dmy (day month year); this is resolved by checking if there are slashes or dashes. If slashes, then it will try dmy first. All other cases will use the international format ymd. Sometimes, if the conditions are right, it can even parse dmy with dashes if the month is a vocal month (eg, &quot;Jan&quot;). If the string starts with 10-11 digits with optional precision, then we&#39;ll try to parse it as a Unix epoch timestamp. If the string starts with 1-5 digits with optional precision, then we&#39;ll try to parse it as a serial timestamp (spreadsheet time) treating 1899-12-31 as 1. This will cause Excel-produced dates from 1900-01-01 until 1900-03-01 to be incorrect, as they really are. If the string represents an integer, then we will parse a date from it. If it is a flaot, then we&#39;ll parse a NaiveDateTime from it. Examples iex&gt; DateTimeParser.parse_datetime(&quot;19 September 2018 08:15:22 AM&quot;) {:ok, ~N[2018-09-19 08:15:22]} iex&gt; DateTimeParser.parse_datetime(&quot;2034-01-13&quot;) {:ok, ~N[2034-01-13 00:00:00]} iex&gt; DateTimeParser.parse_date(&quot;2034-01-13&quot;) {:ok, ~D[2034-01-13]} iex&gt; DateTimeParser.parse_date(&quot;01/01/2017&quot;) {:ok, ~D[2017-01-01]} iex&gt; DateTimeParser.parse_datetime(&quot;1564154204&quot;) {:ok, DateTime.from_naive!(~N[2019-07-26T15:16:44Z], &quot;Etc/UTC&quot;)} iex&gt; DateTimeParser.parse_datetime(&quot;41261.6013888889&quot;) {:ok, ~N[2012-12-18T14:26:00]} iex&gt; DateTimeParser.parse_date(&quot;44262&quot;) {:ok, ~D[2021-03-07]} # This is a serial number date, commonly found in spreadsheets, eg: `=VALUE(&quot;03/07/2021&quot;)` iex&gt; DateTimeParser.parse_datetime(&quot;1/1/18 3:24 PM&quot;) {:ok, ~N[2018-01-01T15:24:00]} iex&gt; DateTimeParser.parse_datetime(&quot;1/1/18 3:24 PM&quot;, assume_utc: true) {:ok, DateTime.from_naive!(~N[2018-01-01T15:24:00Z], &quot;Etc/UTC&quot;)} # or ~U[2018-01-01T15:24:00Z] in Elixir 1.9.0+ iex&gt; DateTimeParser.parse_datetime(~s|&quot;Dec 1, 2018 7:39:53 AM PST&quot;|) {:ok, DateTime.from_naive!(~N[2018-12-01T14:39:53Z], &quot;Etc/UTC&quot;)} # Notice that the date is converted to UTC by default iex&gt; {:ok, datetime} = DateTimeParser.parse_datetime(~s|&quot;Dec 1, 2018 7:39:53 AM PST&quot;|, to_utc: false) iex&gt; datetime #DateTime&lt;2018-12-01 07:39:53-07:00 PDT PST8PDT&gt; iex&gt; DateTimeParser.parse_time(&quot;10:13pm&quot;) {:ok, ~T[22:13:00]} iex&gt; DateTimeParser.parse_time(&quot;10:13:34&quot;) {:ok, ~T[10:13:34]} iex&gt; DateTimeParser.parse_time(&quot;18:14:21.145851000000Z&quot;) {:ok, ~T[18:14:21.145851]} iex&gt; DateTimeParser.parse_datetime(nil) {:error, &quot;Could not parse nil&quot;}"},{"ref":"DateTimeParser.html#parse_date/1","title":"DateTimeParser.parse_date/1","type":"function","doc":"Parse %Date{} from a string."},{"ref":"DateTimeParser.html#parse_datetime/2","title":"DateTimeParser.parse_datetime/2","type":"function","doc":"Parse a %DateTime{} or %NaiveDateTime{} from a string. Options: :assume_utc Default false. Only applicable for strings where parsing could not determine a timezone. Instead of returning a NaiveDateTime, this option will assume them to be in UTC timezone, and therefore return a DateTime :to_utc Default true. If there&#39;s a timezone detected in the string, then attempt to convert to UTC timezone. This is helpful for storing in databases with Ecto."},{"ref":"DateTimeParser.html#parse_time/1","title":"DateTimeParser.parse_time/1","type":"function","doc":"Parse %Time{} from a string."},{"ref":"readme.html","title":"DateTimeParser","type":"extras","doc":"DateTimeParser DateTimeParser is a tokenizer for strings that attempts to parse into a DateTime, NaiveDateTime if timezone is not determined, Date, or Time. The biggest ambiguity between datetime formats is whether it&#39;s ymd (year month day), mdy (month day year), or dmy (day month year); this is resolved by checking if there are slashes or dashes. If slashes, then it will try dmy first. All other cases will use the international format ymd. Sometimes, if the conditions are right, it can even parse dmy with dashes if the month is a vocal month (eg, &quot;Jan&quot;). If the string consists of only numbers, then we will try two other parsers depending on the number of digits: Epoch or Serial. Otherwise, we&#39;ll try the tokenizer. If the string is 10-11 digits with optional precision, then we&#39;ll try to parse it as a Unix Epoch timestamp. If the string is 1-5 digits with optional precision, then we&#39;ll try to parse it as a Serial timestamp (spreadsheet time) treating 1899-12-31 as 1. This will cause Excel-produced dates from 1900-01-01 until 1900-03-01 to be incorrect, as they really are. digitsparserrangenotes 1-5Seriallow = 1900-01-01, high = 2173-10-15. Negative numbers go to 1626-03-17Floats indicate time. Integers do not. 6-9TokenizeranyThis allows for &quot;20190429&quot; to be parsed as 2019-04-29 10-11Epochlow = 1976-03-03T09:46:40, high = 5138-11-16 09:46:39If padded with 0s, then it can capture entire range. Negative numbers not yet supported"},{"ref":"readme.html#planned-breaking-changes","title":"DateTimeParser - Planned Breaking Changes","type":"extras","doc":"parse_datetime currently assumes 00:00:00 time if it cannot be determined. This will likely change in a future version because it&#39;s better to have no information than have wrong information. If you want to assume 00:00:00, that&#39;s fine, but this library shouldn&#39;t assume it for you, or at least make it an option. parse_datetime currently defaults to converting to UTC when the timezone is known. This default may change to keep the original timezone information. This will help for future timestamps since timezone rules change; converting to UTC too early may use rules that become outdated by the time the timestamp arrives. The option to convert to UTC will remain, but may not be default. Introduce parse to parse as much as it can, but return any of the structs, %DateTime{} %NaiveDateTime{} %Date{} or %Time{}. It would be up to you to match on what the result is and do what you will. If you know you want the one specific struct, then you can continue to use the more-specific functions like parse_date."},{"ref":"readme.html#required-reading","title":"DateTimeParser - Required reading","type":"extras","doc":"Elixir DateTime docs Elixir NaiveDateTime docs Elixir Date docs Elixir Time docs Elixir Calendar docs How to save datetimes for future events (when UTC is not the right answer) tldr: rules change, so don&#39;t convert to UTC too early. The future might change the timezone conversion rules."},{"ref":"readme.html#documentation","title":"DateTimeParser - Documentation","type":"extras","doc":"Online Documentation"},{"ref":"readme.html#examples","title":"DateTimeParser - Examples","type":"extras","doc":"iex&gt; DateTimeParser.parse_datetime(&quot;19 September 2018 08:15:22 AM&quot;) {:ok, ~N[2018-09-19 08:15:22]} iex&gt; DateTimeParser.parse_datetime(&quot;2034-01-13&quot;) {:ok, ~N[2034-01-13 00:00:00]} iex&gt; DateTimeParser.parse_date(&quot;2034-01-13&quot;) {:ok, ~D[2034-01-13]} iex&gt; DateTimeParser.parse_date(&quot;01/01/2017&quot;) {:ok, ~D[2017-01-01]} iex&gt; DateTimeParser.parse_datetime(&quot;1/1/18 3:24 PM&quot;) {:ok, ~N[2018-01-01T15:24:00]} iex&gt; DateTimeParser.parse_datetime(&quot;1/1/18 3:24 PM&quot;, assume_utc: true) {:ok, ~U[2018-01-01T15:24:00Z]} # the ~U is a DateTime sigil introduced in Elixir 1.9.0 iex&gt; DateTimeParser.parse_datetime(~s|&quot;Dec 1, 2018 7:39:53 AM PST&quot;|) {:ok, ~U[2018-12-01T14:39:53Z]} # Notice that the date is converted to UTC by default iex&gt; {:ok, datetime} = DateTimeParser.parse_datetime(~s|&quot;Dec 1, 2018 7:39:53 AM PST&quot;|, to_utc: false) iex&gt; datetime #DateTime&lt;2018-12-01 07:39:53-07:00 PDT PST8PDT&gt; iex&gt; DateTimeParser.parse_time(&quot;10:13pm&quot;) {:ok, ~T[22:13:00]} iex&gt; DateTimeParser.parse_time(&quot;10:13:34&quot;) {:ok, ~T[10:13:34]} iex&gt; DateTimeParser.parse_datetime(nil) {:error, &quot;Could not parse nil&quot;} See more examples automatically generated by the tests"},{"ref":"readme.html#installation","title":"DateTimeParser - Installation","type":"extras","doc":"Add date_time_parser to your list of dependencies in mix.exs: def deps do [ {:date_time_parser, &quot;~&gt; 0.2.0&quot;} ] end"},{"ref":"readme.html#changelog","title":"DateTimeParser - Changelog","type":"extras","doc":"View Changelog"},{"ref":"readme.html#contributing","title":"DateTimeParser - Contributing","type":"extras","doc":"How to contribute"},{"ref":"readme.html#special-thanks","title":"DateTimeParser - Special Thanks","type":"extras","doc":""},{"ref":"changelog.html","title":"Changelog","type":"extras","doc":"Changelog"},{"ref":"changelog.html#0-2-0","title":"Changelog - 0.2.0","type":"extras","doc":"Add Serial time support"},{"ref":"changelog.html#0-1-4","title":"Changelog - 0.1.4","type":"extras","doc":"Refactor Support subsecond parsing to 24 digits (yoctoseconds) [thanks @myfreeweb]"},{"ref":"changelog.html#0-1-3","title":"Changelog - 0.1.3","type":"extras","doc":"Support parsing Unix epoch times from strings Fix microsecond parsing"},{"ref":"changelog.html#0-1-2","title":"Changelog - 0.1.2","type":"extras","doc":"Validate days of month. Previously it would allow invalid days such as Feb 30. Now it will check if the year is a leap year and allow up to 29, and otherwise 28 for Feb. It will also reject day 31 on months without 31 days."},{"ref":"changelog.html#0-1-1","title":"Changelog - 0.1.1","type":"extras","doc":"Fix PM 12-hr conversion. The bug would convert 12:34PM to 24:34 which is not valid"},{"ref":"changelog.html#0-1-0","title":"Changelog - 0.1.0","type":"extras","doc":"Add DateTimeParser.parse_datetime/2 Add DateTimeParser.parse_date/1 Add DateTimeParser.parse_time/1"},{"ref":"examples.html","title":"Examples","type":"extras","doc":"Examples InputOutput (ISO 8601)Method 01 Feb 20132013-02-01T00:00:00parse_datetime 03 Jan 2013 10:15:26 -08002013-01-03T18:15:26Zparse_datetime 10/1/2018 :: AM2018-10-01T00:00:00parse_datetime 11 Feb 20132013-02-11T00:00:00parse_datetime 11 Jan 2013 13:26:55 -08002013-01-11T21:26:55Zparse_datetime 12/26/20162016-12-26T00:00:00parse_datetime 24 Sep 20132013-09-24T00:00:00parse_datetime &quot;&quot;=&quot;&quot;9/5/2018&quot;&quot;&quot;2018-09-05parse_date &quot;&quot;=&quot;&quot;9/5/2018&quot;&quot;&quot;2018-09-05T00:00:00parse_datetime &quot;=&quot;&quot;10/1/2018&quot;&quot;&quot;2018-10-01T00:00:00parse_datetime &quot;=&quot;&quot;9/5/2018&quot;&quot;&quot;2018-09-05T00:00:00parse_datetime &quot;Apr 1, 2016 12:02:53 AM PDT&quot;2016-04-01T19:02:53Zparse_datetime &quot;Apr 1, 2017 2:21:25 AM PDT&quot;2017-04-01T09:21:25Zparse_datetime &quot;Dec 1, 2018 7:39:53 AM PST&quot;2018-12-01T14:39:53Zparse_datetime &quot;Jan 1, 2013 06:34:31 PM PST&quot;2013-01-02T01:34:31Zparse_datetime &quot;Jan 1, 2014 6:44:47 AM PST&quot;2014-01-01T13:44:47Zparse_datetime &quot;Nov 16, 2017 9:41:28 PM PST&quot;2017-11-17T04:41:28Zparse_datetime &quot;Nov 20, 2016 22:09:23 PM&quot;2016-11-20T22:09:23parse_datetime &quot;Sat, 29 Sep 2018 21:36:28 -0400&quot;2018-09-30T01:36:28Zparse_datetime &quot;September 28, 2016&quot;2016-09-28T00:00:00parse_datetime &quot;Tuesday, November 29, 2016&quot;2016-11-29T00:00:00parse_datetime -3631899-01-01parse_date -363.01899-01-01T00:00:00parse_datetime -45103.14543981481776-07-04parse_date -45103.145439814820:30:34parse_time -45103.14543981481776-07-04T20:30:34parse_datetime 00000000001970-01-01parse_date 000000000000:00:00parse_time 00000000001970-01-01T00:00:00Zparse_datetime 00:00.000:00:00parse_time 01-01-20182018-01-01T00:00:00parse_datetime 01-Feb-182018-02-01T00:00:00parse_datetime 01-Jul2019-07-01T00:00:00parse_datetime 01-Jul-182018-07-01T00:00:00parse_datetime 01.09.20182018-09-01T00:00:00parse_datetime 01.11.20182018-11-01T00:00:00parse_datetime 01/01/172017-01-01T00:00:00parse_datetime 01/01/20172017-01-01T00:00:00parse_datetime 01/01/2018 - 17:062018-01-01T17:06:00parse_datetime 01/01/2018 01:21PM2018-01-01T13:21:00parse_datetime 01/01/2018 14:442018-01-01T14:44:00parse_datetime 01/01/2018 6:222018-01-01T06:22:00parse_datetime 01/02/162016-01-02T00:00:00parse_datetime 01/02/18 01:02 AM2018-01-02T01:02:00parse_datetime 01/02/20152015-01-02T00:00:00parse_datetime 01/09/20342034-01-09parse_date 01/09/20342034-01-09T00:00:00parse_datetime 01/Jun./20182018-06-01T00:00:00parse_datetime 02-05-20182018-05-02T00:00:00parse_datetime 02-Oct-172017-10-02T00:00:00parse_datetime 02/01/172017-02-01T00:00:00parse_datetime 02/01/20182018-02-01T00:00:00parse_datetime 02/06/20192019-02-06parse_date 02/06/20192019-02-06T00:00:00parse_datetime 02/21/2018 9:37:42 AM2018-02-21T09:37:42parse_datetime 03/5/20182018-03-05T00:00:00parse_datetime 05/01/2018 0:002018-05-01T00:00:00parse_datetime 06/14/2018 09:42:08 PM-05002018-06-15T02:42:08Zparse_datetime 06/28/18 1:252018-06-28T01:25:00parse_datetime 07:09.307:09:00parse_time 08:53.008:53:00parse_time 1-Apr2019-04-01T00:00:00parse_datetime 1//1/172017-01-01T00:00:00parse_datetime 1/1/01170117-01-01T00:00:00parse_datetime 1/1/17 19:122017-01-01T19:12:00parse_datetime 1/1/18 00:012018-01-01T00:01:00parse_datetime 1/1/18 3:24 PM2018-01-01T15:24:00parse_datetime 1/1/19 10:39 AM2019-01-01T10:39:00parse_datetime 1/1/20132013-01-01T00:00:00parse_datetime 1/10/2018 8:38pM2018-01-10T20:38:00parse_datetime 1/13/192019-01-13parse_date 1/13/192019-01-13T00:00:00parse_datetime 1/13/20192019-01-13parse_date 1/13/20192019-01-13T00:00:00parse_datetime 1/15/2019 3:062019-01-15parse_date 1/15/2019 3:062019-01-15T03:06:00parse_datetime 1/17/2018 0:00:002018-01-17T00:00:00parse_datetime 1/2/2018 18:06:262018-01-02T18:06:26parse_datetime 1/3/2019 12:00:00 AM2019-01-03T12:00:00parse_datetime 1/31/2018 0:00:00 UTC2018-01-31T00:00:00Zparse_datetime 1/9/20342034-01-09parse_date 1/9/20342034-01-09T00:00:00parse_datetime 1/9/342034-01-09parse_date 1/9/342034-01-09T00:00:00parse_datetime 10/2/2017 - 23:142017-10-02T23:14:00parse_datetime 10/5/2017 23:522017-10-05T23:52:00parse_datetime 10:13.710:13:00parse_time 11 July 2017 1:43:46 PM2017-07-11parse_date 11 July 2017 1:43:46 PM2017-07-11T13:43:46parse_datetime 18-07-2018 20:38:34 +00:002018-07-18T20:38:34Zparse_datetime 18-12-292018-12-29T00:00:00parse_datetime 19 September 18 2:33:08 PM2018-09-19parse_date 19 September 18 2:33:08 PM2018-09-19T14:33:08parse_datetime 19 September 2018 08:15:22 AM2018-09-19parse_date 19 September 2018 08:15:22 AM2018-09-19T08:15:22parse_datetime 19-Dec-192019-12-19T00:00:00parse_datetime 21900-01-01parse_date 2.01900-01-01T00:00:00parse_datetime 2011-01-01 04:19:20 -0:002011-01-01T04:19:20Zparse_datetime 2012-10-30 09:52:002012-10-30T09:52:00parse_datetime 2012-11-23T22:42:25-05:002012-11-24T03:42:25Zparse_datetime 2013-04-26 11:25:03 UTC2013-04-26T11:25:03Zparse_datetime 2013-09-10 22:14:56.7172013-09-10T22:14:56.717parse_datetime 2013-12-31T22:18:50+00:002013-12-31T22:18:50Zparse_datetime 2015-09-28 10:57:11 -07002015-09-28T17:57:11Zparse_datetime 2015/12/1 1:162015-12-01T01:16:00parse_datetime 2016-02-292016-02-29parse_date 2016-02-29 00:00:00 UTC2016-02-29T00:00:00Zparse_datetime 2016-04-302016-04-30T00:00:00parse_datetime 2016-05-02T01:10:06+00:002016-05-02T01:10:06Zparse_datetime 2016-06-11 15:50:432016-06-11T15:50:43parse_datetime 2016-06-16 06:06:062016-06-16T06:06:06parse_datetime 2016-07-01 01:51:34+002016-07-01T01:51:34Zparse_datetime 2016-07-31 18:42:46-07:002016-08-01T01:42:46Zparse_datetime 2016-08-04T07:00:25Z2016-08-04T07:00:25Zparse_datetime 2016-08-19 09:34:51.02016-08-19T09:34:51.0parse_datetime 2016-11-17 10:36:34.812016-11-17T10:36:34.81parse_datetime 2016-11-23T16:25:33.9718972016-11-23T16:25:33.971897parse_datetime 2016/1/92016-01-09T00:00:00parse_datetime 2017-09-29+00:002017-09-29T00:00:00parse_datetime 2017-10-06+03:45:162017-10-06T03:45:16parse_datetime 2017-10-24 04:00:10 PDT2017-10-24T11:00:10Zparse_datetime 2017-11-04 15:20:47 EDT2017-11-04parse_date 2017-11-04 15:20:47 EDT2017-11-04T19:20:47Zparse_datetime 2017-11-04 15:20:47 EST2017-11-04parse_date 2017-11-04 15:20:47 EST2017-11-04T20:20:47Zparse_datetime 2017-11-04 15:20:47 UTC2017-11-04parse_date 2017-11-04 15:20:47 UTC2017-11-04T15:20:47Zparse_datetime 2017-11-04 15:20:47+00002017-11-04parse_date 2017-11-04 15:20:47+00002017-11-04T15:20:47Zparse_datetime 2017-11-04 15:20:47+05002017-11-04parse_date 2017-11-04 15:20:47+05002017-11-04T10:20:47Zparse_datetime 2017-11-04 15:20:47-05002017-11-04parse_date 2017-11-04 15:20:47-05002017-11-04T20:20:47Zparse_datetime 2017-12-01 03:522017-12-01T03:52:00parse_datetime 2017/08/082017-08-08T00:00:00parse_datetime 2019-05-16+04:002019-05-16parse_date 2019-05-16+04:002019-05-16T04:00:00parse_datetime 2019-05-20 10:00:00PST2019-05-20parse_date 2019-05-20 10:00:00PST2019-05-20T17:00:00Zparse_datetime 2019/01/31 0:012019-01-31T00:01:00parse_datetime 20190118 949 CST2019-01-18T14:49:00Zparse_datetime 2034-01-132034-01-13parse_date 2034-01-132034-01-13T00:00:00parse_datetime 2034-1-92034-01-09parse_date 2034-1-92034-01-09T00:00:00parse_datetime 203401092034-01-09T00:00:00parse_datetime 23-05-2019 @ 10:012019-05-23parse_date 23-05-2019 @ 10:012019-05-23T10:01:00parse_datetime 29/Aug./20182018-08-29T00:00:00parse_datetime 29/Sep./20182018-09-29T00:00:00parse_datetime 34-1-132034-01-13parse_date 34-1-132034-01-13T00:00:00parse_datetime 4/24/2019 0:00:002019-04-24parse_date 4/24/2019 0:00:002019-04-24T00:00:00parse_datetime 41261.60138888892012-12-18parse_date 41261.601388888914:26:00parse_time 41261.60138888892012-12-18T14:26:00parse_datetime 5/12/2019 12:21:58 PM2019-05-12T12:21:58parse_datetime 5/2/2019 0:00:002019-05-02parse_date 5/2/2019 0:00:002019-05-02T00:00:00parse_datetime 5/2/2019 12:00:00 AM2019-05-02parse_date 5/2/2019 12:00:00 AM2019-05-02T12:00:00parse_datetime 5/31/2019 12:00:00 AM2019-05-31parse_date 5/31/2019 12:00:00 AM2019-05-31T12:00:00parse_datetime 621900-03-02parse_date 62.01900-03-02T00:00:00parse_datetime 9-2-322032-02-09parse_date 9-2-322032-02-09T00:00:00parse_datetime 9-Feb-182018-02-09parse_date 9-Feb-182018-02-09T00:00:00parse_datetime 9/1/2018 10:262018-09-01parse_date 9/1/2018 10:262018-09-01T10:26:00parse_datetime 9/10/2018 11:08:13 AM2018-09-10T11:08:13parse_datetime 9/19/2018 20:382018-09-19T20:38:00parse_datetime 9/20/2017 18:57:24 UTC2017-09-20T18:57:24Zparse_datetime 9/4/2018 0:002018-09-04parse_date 9/4/2018 0:002018-09-04T00:00:00parse_datetime 99999999992286-11-20parse_date 999999999917:46:39parse_time 99999999992286-11-20T17:46:39Zparse_datetime 9999999999.9992286-11-20parse_date 9999999999.99917:46:39.999parse_time 9999999999.9992286-11-20T17:46:39.999Zparse_datetime 9999999999.9999992286-11-20parse_date 9999999999.99999917:46:39.999999parse_time 9999999999.9999992286-11-20T17:46:39.999999Zparse_datetime 9999999999.99999999992286-11-20parse_date 9999999999.999999999917:46:39.999999parse_time 9999999999.99999999992286-11-20T17:46:39.999999Zparse_datetime 999999999995138-11-16parse_date 9999999999909:46:39parse_time 999999999995138-11-16T09:46:39Zparse_datetime Fri Mar 2 09:01:57 20182018-03-02T09:01:57parse_datetime Fri Mar 31 2017 21:41:40 GMT+0000 (UTC)2017-03-31T21:41:40Zparse_datetime Friday 02 February 2018 10:42:21 AM2018-02-02T10:42:21parse_datetime Jan-01-192019-01-01T00:00:00parse_datetime Jan-01-20182018-01-01T00:00:00parse_datetime May 30, 2019 4:31:09 AM PDT2019-05-30parse_date May 30, 2019 4:31:09 AM PDT2019-05-30T11:31:09Zparse_datetime Monday 01 October 2018 06:34:19 AM2018-10-01T06:34:19parse_datetime Monday 02 October 2017 9:04:49 AM2017-10-02T09:04:49parse_datetime November 29, 20162016-11-29parse_date November 29, 20162016-11-29T00:00:00parse_datetime Oct 5, 2018 6:16:56 PM PDT2018-10-05parse_date Oct 5, 2018 6:16:56 PM PDT2018-10-06T01:16:56Zparse_datetime Sep-19-162016-09-19parse_date Sep-19-162016-09-19T00:00:00parse_datetime Sun 01 January 2017 10:11:02 PM2017-01-01parse_date Sun 01 January 2017 10:11:02 PM2017-01-01T22:11:02parse_datetime Sun Jan 08 2017 04:28:42 GMT+0000 (UTC)2017-01-08T04:28:42Zparse_datetime Sun Jul 1 00:31:18 20182018-07-01T00:31:18parse_datetime Sun, 01 January 2017 10:11:02 PM2017-01-01parse_date Sun, 01 January 2017 10:11:02 PM2017-01-01T22:11:02parse_datetime Sunday 01 January 2017 09:22:46 AM2017-01-01T09:22:46parse_datetime Sunday 01 January 2017 10:11:02 PM2017-01-01parse_date Sunday 01 January 2017 10:11:02 PM2017-01-01T22:11:02parse_datetime Sunday 01 January 2017 10:11:02 PM2017-01-01T22:11:02parse_datetime Sunday, 01 January 2017 10:11:02 PM2017-01-01parse_date Sunday, 01 January 2017 10:11:02 PM2017-01-01T22:11:02parse_datetime Thu Aug 09 2018 17:13:43 GMT+0000 (UTC)2018-08-09T17:13:43Zparse_datetime Thu Feb 08 00:24:33 20182018-02-08T00:24:33parse_datetime Thu Jul 5 12:19:56 20182018-07-05T12:19:56parse_datetime Thursday 30 August 2018 11:31:18 AM2018-08-30T11:31:18parse_datetime Tue Jul 31 06:44:39 20182018-07-31T06:44:39parse_datetime Tuesday 11 July 2017 1:43:46 PM2017-07-11T13:43:46parse_datetime jul-10-182018-07-10T00:00:00parse_datetime"},{"ref":"license.html","title":"LICENSE","type":"extras","doc":"The MIT License (MIT) Copyright (c) 2018 David Bernheisel Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."}]